@@ -1,5 +1,5 @@
 #
-# (C) 2010-2014, jnw@cpan.org, all rights reserved.
+# (C) 2010-2015, jnw@cpan.org, all rights reserved.
 # Distribute under the same license as Perl itself.
 #
 #
@@ -79,12 +79,12 @@ File::Unpack - A strong bz2/gz/zip/tar/cpio/rpm/deb/cab/lzma/7z/rar/... archive
 
 =head1 VERSION
 
-Version 0.69
+Version 0.70
 =cut
 
 # We'll have 1.x versions only after minfree() has a baseline implementation.
 # Please run perl Makefile.PL after changing the version here.
-our $VERSION = '0.69';
+our $VERSION = '0.70';
 
 POSIX::setlocale(&POSIX::LC_ALL, 'C');
 $ENV{PATH} = '/usr/bin:/bin';
@@ -145,6 +145,9 @@ my @builtin_mime_helpers = (
   [ 'application=x-deb',               qr{deb},    [qw(/usr/bin/ar x %(src)s)] ],
   [ 'application=x-debian-package',    qr{deb},    [qw(/usr/bin/ar x %(src)s)] ],
 
+  # Requires: xar
+  [ 'application=x-xar',               qr{pkg},    [qw(/usr/bin/xar -x -f %(src)s)] ],
+
   # Requires: cabextract
   [ 'application/vnd.ms-cab-compressed', qr{cab},  [qw(/usr/bin/cabextract -q %(src)s)] ],
 
@@ -2415,11 +2418,20 @@ sub mime
     {
       if ($r[2] =~ m{\bcpio\s+archive\b}i)
         {
-	  # Mac pax files are gzipped cpio: 'ASCII cpio archive (pre-SVR4 or odc)'
+	  # OSX pax files are gzipped cpio: 'ASCII cpio archive (pre-SVR4 or odc)'
 	  $r[0] = 'application/x-cpio';
 	}
     }
 
+  if ($r[0] eq 'application/octet-stream')
+    {
+      if ($r[2] =~ m{\bxar\s+archive\b}i)
+        {
+	  # OSX pkg files are xar containers with gzipped cpio's inside.'
+	  $r[0] = 'application/x-xar';
+	}
+    }
+
   my $uncomp_buf = '';
 
   if ($r[0] eq 'application/octet-stream')
